@@ -48,15 +48,18 @@ class ManagedServiceInstance:
         remote_orchestrator: "r_orchestrator.RemoteOrchestrator",
         service_entity_name: str,
         service_id: Optional[UUID] = None,
+        lookback_depth: int = 1,
     ) -> None:
         """
         :param remote_orchestrator: remote_orchestrator to create the service instance  on
         :param service_entity_name: name of the service entity
         :param service_id: manually choose the id of the service instance
+        :param lookback_depth: the amount of states to search for failures if we detect a bad state
         """
         self.remote_orchestrator = remote_orchestrator
         self.service_entity_name = service_entity_name
         self._instance_id = service_id
+        self._lookback = lookback_depth
 
     @property
     def instance_id(self) -> UUID:
@@ -357,6 +360,8 @@ class ManagedServiceInstance:
                 service_entity=self.service_entity_name,
                 service_id=self.instance_id,
                 version=current_state.version,
+                rejection_lookbehind=self._lookback - 1,
+                failure_lookbehind=self._lookback,
             )
             assert result.code == 200, (
                 f"Wrong response code while trying to get the service diagnostic, got {result.code} (expected 200):\n"
